package com.bonus.canteen.core.kitchen.mapper;

import java.util.List;
import com.bonus.canteen.core.kitchen.domain.KitchenStaffIllegalWarning;

/**
 * 厨房员工违规报警Mapper接口
 * 
 * @author xsheng
 * @date 2025-06-16
 */
public interface KitchenStaffIllegalWarningMapper {
    /**
     * 查询厨房员工违规报警
     * 
     * @param illegalWarningId 厨房员工违规报警主键
     * @return 厨房员工违规报警
     */
    public KitchenStaffIllegalWarning selectKitchenStaffIllegalWarningByIllegalWarningId(Long illegalWarningId);

    /**
     * 查询厨房员工违规报警列表
     * 
     * @param kitchenStaffIllegalWarning 厨房员工违规报警
     * @return 厨房员工违规报警集合
     */
    public List<KitchenStaffIllegalWarning> selectKitchenStaffIllegalWarningList(KitchenStaffIllegalWarning kitchenStaffIllegalWarning);

    /**
     * 新增厨房员工违规报警
     * 
     * @param kitchenStaffIllegalWarning 厨房员工违规报警
     * @return 结果
     */
    public int insertKitchenStaffIllegalWarning(KitchenStaffIllegalWarning kitchenStaffIllegalWarning);

    /**
     * 修改厨房员工违规报警
     * 
     * @param kitchenStaffIllegalWarning 厨房员工违规报警
     * @return 结果
     */
    public int updateKitchenStaffIllegalWarning(KitchenStaffIllegalWarning kitchenStaffIllegalWarning);

    /**
     * 删除厨房员工违规报警
     * 
     * @param illegalWarningId 厨房员工违规报警主键
     * @return 结果
     */
    public int deleteKitchenStaffIllegalWarningByIllegalWarningId(Long illegalWarningId);

    /**
     * 批量删除厨房员工违规报警
     * 
     * @param illegalWarningIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKitchenStaffIllegalWarningByIllegalWarningIds(Long[] illegalWarningIds);
}
