package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenStaffIllegalWarning;
import com.bonus.canteen.core.kitchen.service.IKitchenStaffIllegalWarningService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房员工违规报警Controller
 * 
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "厨房员工违规报警接口")
@RestController
@RequestMapping("/kitchen_staff_illegal_warning")
public class KitchenStaffIllegalWarningController extends BaseController {
    @Autowired
    private IKitchenStaffIllegalWarningService kitchenStaffIllegalWarningService;

    /**
     * 查询厨房员工违规报警列表
     */
    @ApiOperation(value = "查询厨房员工违规报警列表")
    //@RequiresPermissions("kitchen:warning:list")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody @Valid KitchenStaffIllegalWarning kitchenStaffIllegalWarning) {
        startPage();
        List<KitchenStaffIllegalWarning> list = kitchenStaffIllegalWarningService.selectKitchenStaffIllegalWarningList(kitchenStaffIllegalWarning);
        return getDataTable(list);
    }

    /**
     * 导出厨房员工违规报警列表
     */
    @ApiOperation(value = "导出厨房员工违规报警列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:warning:export")
    @SysLog(title = "厨房员工违规报警", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出厨房员工违规报警")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenStaffIllegalWarning kitchenStaffIllegalWarning) {
        List<KitchenStaffIllegalWarning> list = kitchenStaffIllegalWarningService.selectKitchenStaffIllegalWarningList(kitchenStaffIllegalWarning);
        ExcelUtil<KitchenStaffIllegalWarning> util = new ExcelUtil<KitchenStaffIllegalWarning>(KitchenStaffIllegalWarning.class);
        util.exportExcel(response, list, "厨房员工违规报警数据");
    }

    /**
     * 获取厨房员工违规报警详细信息
     */
    @ApiOperation(value = "获取厨房员工违规报警详细信息")
    //@RequiresPermissions("kitchen:warning:query")
    @GetMapping(value = "/{illegalWarningId}")
    public AjaxResult getInfo(@PathVariable("illegalWarningId") Long illegalWarningId) {
        return success(kitchenStaffIllegalWarningService.selectKitchenStaffIllegalWarningByIllegalWarningId(illegalWarningId));
    }

    /**
     * 新增厨房员工违规报警
     */
    @ApiOperation(value = "新增厨房员工违规报警")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:warning:add")
    @SysLog(title = "厨房员工违规报警", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增厨房员工违规报警")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenStaffIllegalWarning kitchenStaffIllegalWarning) {
        try {
            return toAjax(kitchenStaffIllegalWarningService.insertKitchenStaffIllegalWarning(kitchenStaffIllegalWarning));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房员工违规报警
     */
    @ApiOperation(value = "修改厨房员工违规报警")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:warning:edit")
    @SysLog(title = "厨房员工违规报警", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改厨房员工违规报警")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenStaffIllegalWarning kitchenStaffIllegalWarning) {
        try {
            return toAjax(kitchenStaffIllegalWarningService.updateKitchenStaffIllegalWarning(kitchenStaffIllegalWarning));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除厨房员工违规报警
     */
    @ApiOperation(value = "删除厨房员工违规报警")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:warning:remove")
    @SysLog(title = "厨房员工违规报警", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除厨房员工违规报警")
	@PostMapping("/del/{illegalWarningIds}")
    public AjaxResult remove(@PathVariable Long[] illegalWarningIds) {
        return toAjax(kitchenStaffIllegalWarningService.deleteKitchenStaffIllegalWarningByIllegalWarningIds(illegalWarningIds));
    }
}
